hasRunningForegroundProcess property

bool get hasRunningForegroundProcess

Whether the shell currently has a running foreground command.

Unix platforms compare the PTY foreground process group with the shell's process group. Windows reports whether the ConPTY shell has a live child process, since ConPTY does not expose Unix-style foreground job control.

Implementation

bool get hasRunningForegroundProcess {
  if (_isDestroyed) return false;
  return _bindings.pty_has_running_foreground_process(_handle) != 0;
}